@@ -1,6 +1,6 @@
 package Net::SFTP::Foreign;
 
-our $VERSION = '0.60';
+our $VERSION = '0.61';
 
 use strict;
 use warnings;
@@ -137,7 +137,7 @@ sub do_init {
     ## XXX Check for extensions.
 }
 
-sub debug { shift->{debug} and print STDERR "sftp: @_" }
+sub debug { shift->{debug} and print STDERR "sftp: @_\n" }
 
 ## Server -> client methods.
 
@@ -369,7 +369,8 @@ sub get {
     my $want = defined wantarray ? 1 : 0;
 
     my $a = $sftp->do_stat($remote) or return;
-    my $handle = $sftp->do_open($remote, SSH2_FXF_READ) or return;
+    my $handle = $sftp->do_open($remote, SSH2_FXF_READ);
+    defined $handle or return;
 
     local *FH;
     if ($local) {
@@ -434,7 +435,8 @@ sub put {
     binmode FH or croak "Can't binmode FH: $!";
 
     my $handle = $sftp->do_open($remote, SSH2_FXF_WRITE | SSH2_FXF_CREAT |
-	SSH2_FXF_TRUNC, $a) or return;  # check status for info
+	SSH2_FXF_TRUNC, $a);
+    defined $handle or return;
 
     my $offset = 0;
     while (1) {
@@ -464,7 +466,8 @@ sub ls {
     my $sftp = shift;
     my($remote, $code) = @_;
     my @dir;
-    my $handle = $sftp->do_opendir($remote) or return;
+    my $handle = $sftp->do_opendir($remote);
+    return unless defined $handle;
     while (1) {
         my $expected_id = $sftp->_send_str_request(SSH2_FXP_READDIR, $handle);
         my $msg = $sftp->get_msg;
